const moduleAlias = require('module-alias');
moduleAlias.addAlias('@', () => __dirname);


const Koa = require('koa');
const favicon = require('koa-favicon');
const helmet = require('koa-helmet');

require("./db");

const jwt = require("./middleware/jwt");
const onerror = require('./middleware/onerror');
const header = require('./middleware/header');
const ratelimit = require('./middleware/ratelimit');

const router = require('./router');
const mount = require('koa-mount');

const apiResponseHandler = require('./middleware/api-response-handler');

const app = new Koa();
app.proxy = true;

app.use(favicon(__dirname + '/favicon.png'));

app.use(helmet());
app.use(onerror);
app.use(header);
app.use(apiResponseHandler());

// router
app.use(jwt);
app.use(ratelimit);
app.use(mount('/', router.routes())).use(router.allowedMethods());

module.exports = app;